@@ -8,7 +8,6 @@ can issue and manage ``tasks`` using the submit, poll, wait, and kill functions.
 ``Task`` attributes are queried to determine status. Functions are
 also provided to access and interrogate files in the ``task``'s working directory. A
 ``manager_poll`` function can be used to poll for STOP signals from the manager.
-
 """
 
 import os
@@ -19,8 +18,7 @@ import time
 
 from libensemble.message_numbers import (
     UNSET_TAG,
-    MAN_SIGNAL_FINISH,
-    MAN_SIGNAL_KILL,
+    MAN_KILL_SIGNALS,
     WORKER_DONE,
     TASK_FAILED,
     WORKER_KILL_ON_TIMEOUT,
@@ -33,7 +31,7 @@ from libensemble.utils.timer import TaskTimer
 
 logger = logging.getLogger(__name__)
 # To change logging level for just this module
-logger.setLevel(logging.DEBUG)
+# logger.setLevel(logging.DEBUG)
 
 STATES = """
 UNKNOWN
@@ -68,7 +66,7 @@ class TimeoutExpired(Exception):
         self.timeout = timeout
 
     def __str__(self):
-        return "Task {} timed out after {} seconds".format(self.task, self.timeout)
+        return f"Task {self.task} timed out after {self.timeout} seconds"
 
 
 def jassert(test, *args):
@@ -83,24 +81,27 @@ class Application:
 
     prefix = "libe_app"
 
-    def __init__(self, full_path, name=None, calc_type="sim", desc=None, pyobj=None):
+    def __init__(self, full_path, name=None, calc_type="sim", desc=None, pyobj=None, precedent=""):
         """Instantiates a new Application instance."""
         self.full_path = full_path
         self.calc_type = calc_type
         self.calc_dir, self.exe = os.path.split(full_path)
+        self.precedent = precedent
 
         if self.exe.endswith(".py"):
-            self.full_path = " ".join((sys.executable, full_path))
+            if not precedent:
+                self.precedent = sys.executable
+
         self.name = name or self.exe
         self.pyobj = pyobj
         self.desc = desc or (self.exe + " app")
         self.gname = "_".join([Application.prefix, self.name])
+        self.app_cmd = " ".join(filter(None, [self.precedent, self.full_path]))
 
 
 class Task:
     """
     Manages the creation, configuration and status of a launchable task
-
     """
 
     prefix = "libe_task"
@@ -123,10 +124,10 @@ class Task:
         self.app_args = app_args
         self.workerID = workerid
 
-        jassert(app is not None, "Task must be created with an app - no app found for task {}".format(self.id))
+        jassert(app is not None, f"Task must be created with an app - no app found for task {self.id}")
 
-        worker_name = "_worker{}".format(self.workerID) if self.workerID else ""
-        self.name = Task.prefix + "_{}{}_{}".format(app.name, worker_name, self.id)
+        worker_name = f"_worker{self.workerID}" if self.workerID else ""
+        self.name = Task.prefix + f"_{app.name}{worker_name}_{self.id}"
         self.stdout = stdout or self.name + ".out"
         self.stderr = stderr or self.name + ".err"
         self.workdir = workdir
@@ -157,7 +158,7 @@ class Task:
         """Opens and reads the named file in the task's workdir"""
         path = os.path.join(self.workdir, filename)
         if not os.path.exists(path):
-            raise ValueError("{} not found in working directory".format(filename))
+            raise ValueError(f"{filename} not found in working directory")
         with open(path) as f:
             return f.read()
 
@@ -191,13 +192,9 @@ class Task:
 
     def _check_poll(self):
         """Check whether polling this task makes sense."""
-        jassert(
-            self.process is not None, "Polled task {} has no process ID - check tasks been launched".format(self.name)
-        )
+        jassert(self.process is not None, f"Polled task {self.name} has no process ID - check tasks been launched")
         if self.finished:
-            logger.debug(
-                "Polled task {} has already finished. " "Not re-polling. Status is {}".format(self.name, self.state)
-            )
+            logger.debug(f"Polled task {self.name} has already finished. Not re-polling. Status is {self.state}")
             return False
         return True
 
@@ -212,7 +209,7 @@ class Task:
             self.errcode = self.process.returncode
             self.success = self.errcode == 0
             self.state = "FINISHED" if self.success else "FAILED"
-            logger.info("Task {} finished with errcode {} ({})".format(self.name, self.errcode, self.state))
+            logger.info(f"Task {self.name} finished with errcode {self.errcode} ({self.state})")
 
     def poll(self):
         """Polls and updates the status attributes of the task"""
@@ -239,8 +236,11 @@ class Task:
         Parameters
         ----------
 
-        timeout:
-            Time in seconds after which a TimeoutExpired exception is raised"""
+        timeout: int or float,  optional
+            Time in seconds after which a TimeoutExpired exception is raised.
+            If not set, then simply waits until completion.
+            Note that the task is not automatically killed on timeout.
+        """
 
         if self.dry_run:
             return
@@ -261,8 +261,12 @@ class Task:
         Parameters
         ----------
 
-        timeout:
-            Time in seconds after which a TimeoutExpired exception is raised"""
+        timeout: int or float,  optional
+            Time in seconds after which a TimeoutExpired exception is raised.
+            If not set, then simply waits until completion.
+            Note that the task is not automatically killed on timeout.
+        """
+
         self.wait(timeout=timeout)
         return self.state
 
@@ -272,8 +276,12 @@ class Task:
         Parameters
         ----------
 
-        timeout:
-            Time in seconds after which a TimeoutExpired exception is raised"""
+        timeout: int or float,  optional
+            Time in seconds after which a TimeoutExpired exception is raised.
+            If not set, then simply waits until completion.
+            Note that the task is not automatically killed on timeout.
+        """
+
         self.wait(timeout=timeout)
         return self.errcode
 
@@ -297,19 +305,17 @@ class Task:
             return
 
         if self.finished:
-            logger.warning(
-                "Trying to kill task that is no longer running. Task {}: Status is {}".format(self.name, self.state)
-            )
+            logger.warning(f"Trying to kill task that is no longer running. Task {self.name}: Status is {self.state}")
             return
 
         if self.process is None:
             time.sleep(0.2)
             jassert(
                 self.process is not None,
-                "Attempting to kill task {} that has no process ID - check tasks been launched".format(self.name),
+                f"Attempting to kill task {self.name} that has no process ID - check tasks been launched",
             )
 
-        logger.info("Killing task {}".format(self.name))
+        logger.info(f"Killing task {self.name}")
         launcher.cancel(self.process, wait_time)
         self.state = "USER_KILLED"
         self.finished = True
@@ -334,7 +340,7 @@ class Executor:
     **Object Attributes:**
 
     :ivar list list_of_tasks: A list of tasks created in this executor
-
+    :ivar int manager_signal: The most recent manager signal received since manager_poll() was called.
     """
 
     executor = None
@@ -350,28 +356,28 @@ class Executor:
         task.timer.start()  # To ensure a start time before poll - will be overwritten unless finished by poll.
         task.submit_time = task.timer.tstart
         while task.state in NOT_STARTED_STATES:
-            time.sleep(0.02)
+            time.sleep(0.001)
             task.poll()
-        logger.debug("Task {} polled as {} after {} seconds".format(task.name, task.state, time.time() - start))
+        logger.debug(f"Task {task.name} polled as {task.state} after {time.time() - start} seconds")
         if not task.finished:
             task.timer.start()
             task.submit_time = task.timer.tstart
             if fail_time:
                 remaining = fail_time - task.timer.elapsed
                 while task.state not in END_STATES and remaining > 0:
-                    time.sleep(min(0.2, remaining))
+                    time.sleep(min(0.01, remaining))
                     task.poll()
                     remaining = fail_time - task.timer.elapsed
-                logger.debug("After {} seconds: task {} polled as {}".format(task.timer.elapsed, task.name, task.state))
+                logger.debug(f"After {task.timer.elapsed} seconds: task {task.name} polled as {task.state}")
 
     def __init__(self):
         """Instantiate a new Executor instance.
 
         A new Executor object is created.
         This is typically created in the user calling script.
-
         """
-        self.manager_signal = "none"
+
+        self.manager_signal = None
         self.default_apps = {"sim": None, "gen": None}
         self.apps = {}
 
@@ -379,6 +385,7 @@ class Executor:
         self.list_of_tasks = []
         self.workerID = None
         self.comm = None
+        self.last_task = 0
         Executor.executor = self
 
     def __enter__(self):
@@ -408,7 +415,7 @@ class Executor:
         except KeyError:
             app_keys = list(self.apps.keys())
             raise ExecutorException(
-                "Application {} not found in registry".format(app_name), "Registered applications: {}".format(app_keys)
+                f"Application {app_name} not found in registry", f"Registered applications: {app_keys}"
             )
         return app
 
@@ -416,14 +423,14 @@ class Executor:
         """Gets the default app for a given calc type"""
         app = self.default_apps.get(calc_type)
         jassert(calc_type in ["sim", "gen"], "Unrecognized calculation type", calc_type)
-        jassert(app, "Default {} app is not set".format(calc_type))
+        jassert(app, f"Default {calc_type} app is not set")
         return app
 
     def set_resources(self, resources):
         # Does not use resources
         pass
 
-    def register_app(self, full_path, app_name=None, calc_type=None, desc=None):
+    def register_app(self, full_path, app_name=None, calc_type=None, desc=None, precedent=""):
         """Registers a user application to libEnsemble.
 
         The ``full_path`` of the application must be supplied. Either
@@ -447,10 +454,13 @@ class Executor:
         desc: String, optional
             Description of this application
 
+        precedent: String, optional
+            Any string that should directly precede the application full path.
         """
+
         if not app_name:
             app_name = os.path.split(full_path)[1]
-        self.apps[app_name] = Application(full_path, app_name, calc_type, desc)
+        self.apps[app_name] = Application(full_path, app_name, calc_type, desc, None, precedent)
 
         # Default sim/gen apps will be deprecated. Just use names.
         if calc_type is not None:
@@ -464,10 +474,9 @@ class Executor:
         Polls for a manager signal
 
         The executor manager_signal attribute will be updated.
-
         """
 
-        self.manager_signal = "none"  # Reset
+        self.manager_signal = None  # Reset
 
         # Check for messages; disregard anything but a stop signal
         if not self.comm.mail_flag():
@@ -477,16 +486,23 @@ class Executor:
             return
 
         # Process the signal and push back on comm (for now)
-        logger.info("Worker received kill signal {} from manager".format(man_signal))
-        if man_signal == MAN_SIGNAL_FINISH:
-            self.manager_signal = "finish"
-        elif man_signal == MAN_SIGNAL_KILL:
-            self.manager_signal = "kill"
+        self.manager_signal = man_signal
+
+        if man_signal in MAN_KILL_SIGNALS:
+            # Only kill signals exist currently
+            logger.info(f"Worker received kill signal {man_signal} from manager")
         else:
-            logger.warning("Received unrecognized manager signal {} - ignoring".format(man_signal))
+            logger.warning(f"Received unrecognized manager signal {man_signal} - ignoring")
         self.comm.push_to_buffer(mtag, man_signal)
         return man_signal
 
+    def manager_kill_received(self):
+        """Return True if received kill signal from the manager"""
+        man_signal = self.manager_poll()
+        if man_signal in MAN_KILL_SIGNALS:
+            return True
+        return False
+
     def polling_loop(self, task, timeout=None, delay=0.1, poll_manager=False):
         """Optional, blocking, generic task status polling loop. Operates until the task
         finishes, times out, or is optionally killed via a manager signal. On completion, returns a
@@ -515,7 +531,6 @@ class Executor:
         -------
         calc_status: int
             presumptive integer attribute describing the final status of a launched task
-
         """
 
         calc_status = UNSET_TAG
@@ -525,7 +540,7 @@ class Executor:
 
             if poll_manager:
                 man_signal = self.manager_poll()
-                if self.manager_signal != "none":
+                if self.manager_signal in MAN_KILL_SIGNALS:
                     task.kill()
                     calc_status = man_signal
                     break
@@ -543,9 +558,7 @@ class Executor:
             elif task.state == "FAILED":
                 calc_status = TASK_FAILED
             else:
-                logger.warning(
-                    "Warning: Task {} in unknown state {}. Error code {}".format(self.name, self.state, self.errcode)
-                )
+                logger.warning(f"Warning: Task {self.name} in unknown state {self.state}. Error code {self.errcode}")
 
         return calc_status
 
@@ -553,9 +566,30 @@ class Executor:
         """Returns the task object for the supplied task ID"""
         task = next((j for j in self.list_of_tasks if j.id == taskid), None)
         if task is None:
-            logger.warning("Task {} not found in tasklist".format(taskid))
+            logger.warning(f"Task {taskid} not found in tasklist")
         return task
 
+    def new_tasks_timing(self, datetime=False):
+        """Returns timing of new tasks as a string
+
+        Parameters
+        ----------
+
+        datetime: boolean
+            If True, returns start and end times in addition to elapsed time.
+        """
+
+        timing_msg = ""
+        if self.list_of_tasks:
+            start_task = self.last_task
+            for i, task in enumerate(self.list_of_tasks[start_task:]):
+                if datetime:
+                    timing_msg += f" Task {i}: {task.timer}"
+                else:
+                    timing_msg += f" Task {i}: {task.timer.summary()}"
+                self.last_task += 1
+        return timing_msg
+
     def set_workerID(self, workerid):
         """Sets the worker ID for this executor"""
         self.workerID = workerid
@@ -565,6 +599,11 @@ class Executor:
         self.workerID = workerid
         self.comm = comm
 
+    def _check_app_exists(self, full_path):
+        """Allows submit function to check if app exists and error if not"""
+        if not os.path.isfile(full_path):
+            raise ExecutorException(f"Application does not exist {full_path}")
+
     def submit(
         self, calc_type=None, app_name=None, app_args=None, stdout=None, stderr=None, dry_run=False, wait_on_start=False
     ):
@@ -605,7 +644,6 @@ class Executor:
 
         task: obj: Task
             The launched task object
-
         """
 
         if app_name is not None:
@@ -617,15 +655,19 @@ class Executor:
 
         default_workdir = os.getcwd()
         task = Task(app, app_args, default_workdir, stdout, stderr, self.workerID)
-        runline = task.app.full_path.split()
+
+        if not dry_run:
+            self._check_app_exists(task.app.full_path)
+
+        runline = task.app.app_cmd.split()
         if task.app_args is not None:
             runline.extend(task.app_args.split())
 
         if dry_run:
-            logger.info("Test (No submit) Runline: {}".format(" ".join(runline)))
+            logger.info(f"Test (No submit) Runline: {' '.join(runline)}")
         else:
             # Launch Task
-            logger.info("Launching task {}: {}".format(task.name, " ".join(runline)))
+            logger.info(f"Launching task {task.name}: {' '.join(runline)}")
             with open(task.stdout, "w") as out, open(task.stderr, "w") as err:
                 task.process = launcher.launch(
                     runline,
@@ -637,7 +679,7 @@ class Executor:
             if wait_on_start:
                 self._wait_on_start(task, 0)  # No fail time as no re-starts in-place
 
-            if not task.timer.timing:
+            if not task.timer.timing and not task.finished:
                 task.timer.start()
                 task.submit_time = task.timer.tstart  # Time not date - may not need if using timer.
 
