@@ -6,7 +6,6 @@ __all__ = ['LocalOptInterfacer', 'run_local_nlopt', 'run_local_tao',
            'run_local_dfols', 'run_local_scipy_opt', 'run_external_localopt']
 
 import psutil
-from libensemble.tools.tools import osx_set_mp_method
 import numpy as np
 from libensemble.message_numbers import STOP_TAG, EVAL_GEN_TAG  # Only used to simulate receiving from manager
 from multiprocessing import Event, Process, Queue
@@ -15,9 +14,6 @@ import libensemble.gen_funcs
 optimizer_list = ['petsc', 'nlopt', 'dfols', 'scipy', 'external']
 optimizers = libensemble.gen_funcs.rc.aposmm_optimizers
 
-# Resolves multiprocessing issues with Python 3.8+ on macOS
-osx_set_mp_method()
-
 if optimizers is None:
     from petsc4py import PETSc
     import nlopt
@@ -28,7 +24,7 @@ else:
         optimizers = [optimizers]
     unrec = set(optimizers) - set(optimizer_list)
     if unrec:
-        print('APOSMM Warning: unrecognized optimizers {}'.format(unrec))
+        print(f'APOSMM Warning: unrecognized optimizers {unrec}')
 
     if 'petsc' in optimizers:
         from petsc4py import PETSc
@@ -252,7 +248,6 @@ def run_local_scipy_opt(user_specs, comm_queue, x0, f0, child_can_read, parent_c
     Runs a SciPy local optimization run starting at ``x0``, governed by the
     parameters in ``user_specs``.
     """
-
     # Construct the bounds in the form of constraints
     cons = []
     for factor in range(len(x0)):
@@ -309,7 +304,7 @@ def run_external_localopt(user_specs, comm_queue, x0, f0, child_can_read, parent
 
     # cmd = ["matlab", "-nodisplay", "-nodesktop", "-nojvm", "-nosplash", "-r",
     cmd = ["octave", "--no-window-system", "--eval",
-           "x0=[" + " ".join(["{:18.18f}".format(x) for x in x0]) + "];"
+           "x0=[" + " ".join([f"{x:18.18f}" for x in x0]) + "];"
            "opt_file='" + opt_file + "';"
            "x_file='" + x_file + "';"
            "y_file='" + y_file + "';"
@@ -343,7 +338,6 @@ def run_local_dfols(user_specs, comm_queue, x0, f0, child_can_read, parent_can_r
     Runs a DFOLS local optimization run starting at ``x0``, governed by the
     parameters in ``user_specs``.
     """
-
     # Define bound constraints (lower <= x <= upper)
     lb = np.zeros(len(x0))
     ub = np.ones(len(x0))
@@ -381,7 +375,6 @@ def run_local_tao(user_specs, comm_queue, x0, f0, child_can_read, parent_can_rea
     Runs a PETSc/TAO local optimization run starting at ``x0``, governed by the
     parameters in ``user_specs``.
     """
-
     assert isinstance(x0, np.ndarray)
 
     tao_comm = PETSc.COMM_SELF
@@ -426,7 +419,7 @@ def run_local_tao(user_specs, comm_queue, x0, f0, child_can_read, parent_can_rea
         g.setSizes(n)
         g.setFromOptions()
         tao.setObjectiveGradient(lambda tao, x, g: tao_callback_fun_grad(tao, x, g, comm_queue, child_can_read,
-                                                                         parent_can_read, user_specs))
+                                                                         parent_can_read, user_specs), None)
 
     # Set everything for tao before solving
     PETSc.Options().setValue('-tao_max_funcs', str(user_specs.get('run_max_eval', 1000*n)))
@@ -563,10 +556,10 @@ def simulate_recv_from_manager(local_H, gen_specs):
     # output as if the calculations were performed externally by libEnsemble.
     user = gen_specs['user']['standalone']
 
-    if np.sum(local_H['returned']) >= user['eval_max']:
+    if np.sum(local_H['sim_ended']) >= user['eval_max']:
         return STOP_TAG, {}, {}
 
-    H_rows = np.where(~local_H['returned'])[0]
+    H_rows = np.where(~local_H['sim_ended'])[0]
     H_fields = [i[0] for i in gen_specs['out']]
 
     Work = {'libE_info': {'H_rows': H_rows}, 'H_fields': H_fields}
