@@ -75,7 +75,7 @@ def aposmm(H, persis_info, gen_specs, libE_info):
       If more sample points are needed by APOSMM during the course of the
       optimization, points will be drawn uniformly over the domain
     - ``'components' [int]``: Number of objective components
-    - ``'dist_to_bound_multiple' [float in (0,1]]``: What fraction of the
+    - ``'dist_to_bound_multiple' [float in (0, 1]]``: What fraction of the
       distance to the nearest boundary should the initial step size be in
       localopt runs
     - ``'lhs_divisions' [int]``: Number of Latin hypercube sampling partitions
@@ -261,7 +261,7 @@ def update_local_H_after_receiving(local_H, n, n_s, user_specs, Work, calc_in, f
     for name in calc_in.dtype.names:
         local_H[name][Work['libE_info']['H_rows']] = calc_in[name]
 
-    local_H['returned'][Work['libE_info']['H_rows']] = True
+    local_H['sim_ended'][Work['libE_info']['H_rows']] = True
     n_s += np.sum(~local_H[Work['libE_info']['H_rows']]['local_pt'])
     n_r = len(Work['libE_info']['H_rows'])
 
@@ -323,7 +323,7 @@ def update_history_dist(H, n):
 
     new_inds = np.where(~H['known_to_aposmm'])[0]
 
-    p = np.logical_and.reduce((H['returned'], ~np.isnan(H['f'])))
+    p = np.logical_and.reduce((H['sim_ended'], ~np.isnan(H['f'])))
 
     for new_ind in new_inds:
         # Loop over new returned points and update their distances
@@ -370,8 +370,8 @@ def update_history_dist(H, n):
             #     H['worse_within_rk'][new_ind][p] = np.logical_and.reduce((H['f'][new_ind] <= H['f'][p], dist_to_all <= r_k))
 
             #     # Add trues if new point is 'worse_within_rk'
-            #     inds_to_change = np.logical_and.reduce((H['dist_to_all'][p,new_ind] <= r_k, H['f'][new_ind] >= H['f'][p], H['sim_id'][p] != new_ind))
-            #     H['worse_within_rk'][inds_to_change,new_ind] = True
+            #     inds_to_change = np.logical_and.reduce((H['dist_to_all'][p, new_ind] <= r_k, H['f'][new_ind] >= H['f'][p], H['sim_id'][p] != new_ind))
+            #     H['worse_within_rk'][inds_to_change, new_ind] = True
 
             #     if not H['local_pt'][new_ind]:
             #         H['worse_within_rk'][H['dist_to_all'] > r_k] = False
@@ -400,7 +400,7 @@ def update_history_optimal(x_opt, opt_flag, H, run_inds):
     Updated the history after any point has been declared a local minimum
     """
 
-    # opt_ind = np.where(np.logical_and(np.equal(x_opt,H['x_on_cube']).all(1),~np.isinf(H['f'])))[0] # This fails on some problems. x_opt is 1e-16 away from the point that was given and opt_ind is empty
+    # opt_ind = np.where(np.logical_and(np.equal(x_opt, H['x_on_cube']).all(1), ~np.isinf(H['f'])))[0] # This fails on some problems. x_opt is 1e-16 away from the point that was given and opt_ind is empty
     run_inds = np.unique(run_inds)
 
     dists = np.linalg.norm(H['x_on_cube'][run_inds]-x_opt, axis=1)
@@ -420,10 +420,10 @@ def update_history_optimal(x_opt, opt_flag, H, run_inds):
     failsafe = np.logical_and(H['f'][run_inds] < H['f'][opt_ind], dists < tol_x2)
     if opt_flag:
         if np.any(failsafe):
-            print("[APOSMM] This run has {} point(s) with smaller 'f' value within {} of "
+            print(f"[APOSMM] This run has {sum(failsafe)} point(s) with smaller 'f' value within {tol_x2} of "
                   "the point ruled to be the run minimum. \nMarking all as being "
                   "a 'local_min' to prevent APOSMM from starting another run "
-                  "immediately from these points.".format(sum(failsafe), tol_x2))
+                  "immediately from these points.")
             print("[APOSMM] Sim_ids to be marked optimal: ", opt_ind, run_inds[failsafe])
             print("[APOSMM] Check that the local optimizer is working correctly", flush=True)
             H['local_min'][run_inds[failsafe]] = 1
@@ -491,7 +491,7 @@ def decide_where_to_start_localopt(H, n, n_s, rk_const, ld=0, mu=0, nu=0):
 
     if nu > 0:
         test_2_through_5 = np.logical_and.reduce((
-            H['returned'] == 1,  # have a returned function value
+            H['sim_ended'] == 1,  # have a returned function value
             H['dist_to_better_s'] >
             r_k,  # no better sample point within r_k (L2)
             ~H['started_run'],  # have not started a run (L3)
@@ -503,7 +503,7 @@ def decide_where_to_start_localopt(H, n, n_s, rk_const, ld=0, mu=0, nu=0):
         ))
     else:
         test_2_through_5 = np.logical_and.reduce((
-            H['returned'] == 1,  # have a returned function value
+            H['sim_ended'] == 1,  # have a returned function value
             H['dist_to_better_s'] >
             r_k,  # no better sample point within r_k (L2)
             ~H['started_run'],  # have not started a run (L3)
@@ -560,7 +560,6 @@ def decide_where_to_start_localopt(H, n, n_s, rk_const, ld=0, mu=0, nu=0):
 
 def calc_rk(n, n_s, rk_const, lhs_divisions=0):
     """ Calculate the critical distance r_k """
-
     if lhs_divisions == 0:
         r_k = rk_const*(log(n_s)/n_s)**(1/n)
     else:
@@ -605,7 +604,7 @@ def initialize_APOSMM(H, user_specs, libE_info):
                       ('local_min', bool),
                       ('sim_id', int),
                       ('paused', bool),
-                      ('returned', bool),
+                      ('sim_ended', bool),
                       ]
 
     if 'components' in user_specs:
@@ -623,7 +622,7 @@ def initialize_APOSMM(H, user_specs, libE_info):
 
         assert 'f' in H.dtype.names, "Must give 'f' values to persistent_aposmm in gen_specs['in']"
         assert 'sim_id' in H.dtype.names, "Must give 'sim_id' to persistent_aposmm in gen_specs['in']"
-        assert 'returned' in H.dtype.names, "Must give 'returned' status to persistent_aposmm in gen_specs['in']"
+        assert 'sim_ended' in H.dtype.names, "Must give 'sim_ended' status to persistent_aposmm in gen_specs['in']"
 
         over_written_fields = ['dist_to_unit_bounds', 'dist_to_better_l', 'dist_to_better_s', 'ind_of_better_l', 'ind_of_better_s']
         if any([i in H.dtype.names for i in over_written_fields]):
@@ -660,7 +659,7 @@ def initialize_children(user_specs):
     elif user_specs['localopt_method'] in ['pounders', 'dfols']:
         fields_to_pass = ['x_on_cube', 'fvec']
     else:
-        raise NotImplementedError("Unknown local optimization method " "'{}'.".format(user_specs['localopt_method']))
+        raise NotImplementedError(f"Unknown local optimization method {user_specs['localopt_method']}.")
 
     return local_opters, sim_id_to_child_inds, run_order, run_pts, total_runs, fields_to_pass
 
