@@ -28,24 +28,24 @@ may resemble:
 
     nworkers, is_manager, libE_specs, _ = parse_args()
 
-    libE_specs['save_every_k_gens'] = 20
+    libE_specs["save_every_k_gens"] = 20
 
-    gen_specs = {'gen_f': gen_random_sample,
-                 'out': [('x', float, (1,))],
-                 'user': {
-                    'lower': np.array([-3]),
-                    'upper': np.array([3]),
-                    'gen_batch_size': 5
+    gen_specs = {"gen_f": gen_random_sample,
+                 "out": [("x", float, (1,))],
+                 "user": {
+                    "lower": np.array([-3]),
+                    "upper": np.array([3]),
+                    "gen_batch_size": 5
                     }
                  }
 
-    sim_specs = {'sim_f': sim_find_sine,
-                 'in': ['x'],
-                 'out': [('y', float)]}
+    sim_specs = {"sim_f": sim_find_sine,
+                 "in": ["x"],
+                 "out": [("y", float)]}
 
     persis_info = add_unique_random_streams({}, nworkers+1)
 
-    exit_criteria = {'sim_max': 80}
+    exit_criteria = {"sim_max": 80}
 
     H, persis_info, flag = libE(sim_specs, gen_specs, exit_criteria, persis_info,
                                 libE_specs=libE_specs)
@@ -66,10 +66,10 @@ to be installed. The equivalent of above resembles:
     from libensemble import Ensemble
 
     my_experiment = Ensemble()
-    my_experiment.from_yaml('my_parameters.yaml')
+    my_experiment.from_yaml("my_parameters.yaml")
 
-    my_experiment.gen_specs['user']['lower'] = np.array([-3])
-    my_experiment.gen_specs['user']['upper'] = np.array([3])
+    my_experiment.gen_specs["user"]["lower"] = np.array([-3])
+    my_experiment.gen_specs["user"]["upper"] = np.array([3])
 
     H, persis_info, flag = my_experiment.run()
 
@@ -100,6 +100,54 @@ The remaining parameters may be found in a ``yaml`` file that resembles:
             y:
                 type: float
 
+On macOS (since Python 3.8) and Windows, the default multiprocessing start method is ``'spawn'``
+and you must place most calling script code (or just ``libE()`` / ``Ensemble().run()`` at a minimum) in
+an ``if __name__ == "__main__:"`` block.
+
+Therefore a calling script that is universal across
+all platforms and comms-types may resemble:
+
+.. code-block:: python
+    :linenos:
+
+    import numpy as np
+    from libensemble.libE import libE
+    from generator import gen_random_sample
+    from simulator import sim_find_sine
+    from libensemble.tools import add_unique_random_streams
+
+    if __name__ == "__main__:
+
+        nworkers, is_manager, libE_specs, _ = parse_args()
+
+        libE_specs["save_every_k_gens"] = 20
+
+        gen_specs = {"gen_f": gen_random_sample,
+                    "out": [("x", float, (1,))],
+                    "user": {
+                        "lower": np.array([-3]),
+                        "upper": np.array([3]),
+                        "gen_batch_size": 5
+                        }
+                    }
+
+        sim_specs = {"sim_f": sim_find_sine,
+                    "in": ["x"],
+                    "out": [("y", float)]}
+
+        persis_info = add_unique_random_streams({}, nworkers+1)
+
+        exit_criteria = {"sim_max": 80}
+
+        H, persis_info, flag = libE(sim_specs, gen_specs, exit_criteria, persis_info,
+                                    libE_specs=libE_specs)
+
+Alternatively, you may set the multiprocessing start method to ``'fork'`` via the following:
+
+    from multiprocessing import set_start_method
+    set_start_method("fork")
+
+But note that this is incompatible with some libraries.
 
 See below for the complete traditional ``libE()`` API.
 """
@@ -126,8 +174,9 @@ from libensemble.comms.logs import manager_logging_config
 from libensemble.comms.tcp_mgr import ServerQCommManager, ClientQCommManager
 from libensemble.executors.executor import Executor
 from libensemble.resources.resources import Resources
-from libensemble.tools.tools import _USER_SIM_ID_WARNING, osx_set_mp_method
+from libensemble.tools.tools import _USER_SIM_ID_WARNING
 from libensemble.tools.check_inputs import check_inputs
+from libensemble.tools.alloc_support import AllocSupport
 
 logger = logging.getLogger(__name__)
 # To change logging level for just this module
@@ -221,7 +270,7 @@ def libE(sim_specs, gen_specs, exit_criteria, persis_info=None, alloc_specs=None
 
     comms_type = libE_specs.get("comms")
 
-    assert comms_type in libE_funcs, "Unknown comms type: {}".format(comms_type)
+    assert comms_type in libE_funcs, f"Unknown comms type: {comms_type}"
 
     # Resource management not supported with TCP
     if comms_type == "tcp":
@@ -229,6 +278,9 @@ def libE(sim_specs, gen_specs, exit_criteria, persis_info=None, alloc_specs=None
 
     Resources.init_resources(libE_specs)
 
+    # Reset gen counter.
+    AllocSupport.gen_counter = 0
+
     return libE_funcs[comms_type](sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, libE_specs, H0)
 
 
@@ -245,12 +297,12 @@ def manager(
     on_cleanup=None,
 ):
     """Generic manager routine run."""
-
     logger.info("Logger initializing: [workerID] precedes each line. [0] = Manager")
-    logger.info("libE version v{}".format(__version__))
+    logger.info(f"libE version v{__version__}")
 
     if "out" in gen_specs and ("sim_id", int) in gen_specs["out"]:
-        logger.manager_warning(_USER_SIM_ID_WARNING)
+        if "libensemble.gen_funcs" not in gen_specs["gen_f"].__module__:
+            logger.manager_warning(_USER_SIM_ID_WARNING)
 
     save_H = libE_specs.get("save_H_and_persis_on_abort", True)
 
@@ -259,7 +311,7 @@ def manager(
             persis_info, exit_flag, elapsed_time = manager_main(
                 hist, libE_specs, alloc_specs, sim_specs, gen_specs, exit_criteria, persis_info, wcomms
             )
-            logger.info("Manager total time: {}".format(elapsed_time))
+            logger.info(f"Manager total time: {elapsed_time}")
         except LoggedException:
             # Exception already logged in manager
             raise
@@ -273,12 +325,13 @@ def manager(
         exit_flag = 1  # Only exits if no abort/raise
         _dump_on_abort(hist, persis_info, save_H=save_H)
         if libE_specs.get("abort_on_exception", True) and on_abort is not None:
+            on_cleanup()
             on_abort()
         raise LoggedException(*e.args, "See error details above and in ensemble.log") from None
     else:
         logger.debug("Manager exiting")
-        logger.debug("Exiting with {} workers.".format(len(wcomms)))
-        logger.debug("Exiting with exit criteria: {}".format(exit_criteria))
+        logger.debug(f"Exiting with {len(wcomms)} workers.")
+        logger.debug(f"Exiting with exit criteria: {exit_criteria}")
     finally:
         if on_cleanup is not None:
             on_cleanup()
@@ -311,7 +364,6 @@ def comms_abort(mpi_comm):
 
 def libE_mpi_defaults(libE_specs):
     """Fill in default values for MPI-based communicators."""
-
     from mpi4py import MPI
 
     if "mpi_comm" not in libE_specs:
@@ -322,7 +374,6 @@ def libE_mpi_defaults(libE_specs):
 
 def libE_mpi(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, libE_specs, H0):
     """MPI version of the libE main routine"""
-
     libE_specs, mpi_comm_null = libE_mpi_defaults(libE_specs)
 
     if libE_specs["mpi_comm"] == mpi_comm_null:
@@ -362,7 +413,6 @@ def libE_mpi(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, libE
 
 def libE_mpi_manager(mpi_comm, sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, libE_specs, H0):
     """Manager routine runs on rank 0."""
-
     from libensemble.comms.mpi import MainMPIComm
 
     hist = History(alloc_specs, sim_specs, gen_specs, exit_criteria, H0)
@@ -371,7 +421,14 @@ def libE_mpi_manager(mpi_comm, sim_specs, gen_specs, exit_criteria, persis_info,
     wcomms = [MainMPIComm(mpi_comm, w) for w in range(1, mpi_comm.Get_size())]
 
     if not libE_specs.get("disable_log_files", False):
-        manager_logging_config()
+        exit_logger = manager_logging_config()
+    else:
+        exit_logger = None
+
+    def cleanup():
+        """Process cleanup required on exit"""
+        if exit_logger is not None:
+            exit_logger()
 
     # Set up abort handler
     def on_abort():
@@ -380,18 +437,26 @@ def libE_mpi_manager(mpi_comm, sim_specs, gen_specs, exit_criteria, persis_info,
 
     # Run generic manager
     return manager(
-        wcomms, sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, libE_specs, hist, on_abort=on_abort
+        wcomms,
+        sim_specs,
+        gen_specs,
+        exit_criteria,
+        persis_info,
+        alloc_specs,
+        libE_specs,
+        hist,
+        on_abort=on_abort,
+        on_cleanup=cleanup,
     )
 
 
 def libE_mpi_worker(libE_comm, sim_specs, gen_specs, libE_specs):
     """Worker routines run on ranks > 0."""
-
     from libensemble.comms.mpi import MainMPIComm
 
     comm = MainMPIComm(libE_comm)
     worker_main(comm, sim_specs, gen_specs, libE_specs, log_comm=True)
-    logger.debug("Worker {} exiting".format(libE_comm.Get_rank()))
+    logger.debug(f"Worker {libE_comm.Get_rank()} exiting")
 
 
 # ==================== Local version ===============================
@@ -399,7 +464,14 @@ def libE_mpi_worker(libE_comm, sim_specs, gen_specs, libE_specs):
 
 def start_proc_team(nworkers, sim_specs, gen_specs, libE_specs, log_comm=True):
     """Launch a process worker team."""
-    wcomms = [QCommProcess(worker_main, sim_specs, gen_specs, libE_specs, w, log_comm) for w in range(1, nworkers + 1)]
+    resources = Resources.resources
+    executor = Executor.executor
+
+    wcomms = [
+        QCommProcess(worker_main, nworkers, sim_specs, gen_specs, libE_specs, w, log_comm, resources, executor)
+        for w in range(1, nworkers + 1)
+    ]
+
     for wcomm in wcomms:
         wcomm.run()
     return wcomms
@@ -416,7 +488,6 @@ def kill_proc_team(wcomms, timeout):
 
 def libE_local(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, libE_specs, H0):
     """Main routine for thread/process launch of libE."""
-
     nworkers = libE_specs["nworkers"]
 
     check_inputs(libE_specs, alloc_specs, sim_specs, gen_specs, exit_criteria, H0)
@@ -433,13 +504,6 @@ def libE_local(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, li
 
     hist = History(alloc_specs, sim_specs, gen_specs, exit_criteria, H0)
 
-    # On Python 3.8 on macOS, the default start method for new processes was
-    #  switched to 'spawn' by default due to 'fork' potentially causing crashes.
-    # These crashes haven't yet been observed with libE, but with 'spawn' runs,
-    #  warnings about leaked semaphore objects are displayed instead.
-    # This function enforces 'fork' on macOS (Python 3.8)
-    osx_set_mp_method()
-
     # Launch worker team and set up logger
     wcomms = start_proc_team(nworkers, sim_specs, gen_specs, libE_specs)
 
@@ -448,16 +512,16 @@ def libE_local(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, li
         resources.set_resource_manager(nworkers)
 
     if not libE_specs.get("disable_log_files", False):
-        close_logs = manager_logging_config()
+        exit_logger = manager_logging_config()
     else:
-        close_logs = None
+        exit_logger = None
 
     # Set up cleanup routine to shut down worker team
     def cleanup():
         """Handler to clean up comms team."""
         kill_proc_team(wcomms, timeout=libE_specs.get("worker_timeout", 1))
-        if close_logs is not None:  # logger remains set between multiple libE calls
-            close_logs()
+        if exit_logger is not None:
+            exit_logger()
 
     # Run generic manager
     return manager(
@@ -479,17 +543,16 @@ def get_ip():
 def libE_tcp_authkey():
     """Generate an authkey if not assigned by manager."""
     nonce = random.randrange(99999)
-    return "libE_auth_{}".format(nonce)
+    return f"libE_auth_{nonce}"
 
 
 def libE_tcp_default_ID():
     """Assign a (we hope unique) worker ID if not assigned by manager."""
-    return "{}_pid{}".format(get_ip(), os.getpid())
+    return f"{get_ip()}_pid{os.getpid()}"
 
 
 def libE_tcp(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, libE_specs, H0):
     """Main routine for TCP multiprocessing launch of libE."""
-
     check_inputs(libE_specs, alloc_specs, sim_specs, gen_specs, exit_criteria, H0)
 
     is_worker = True if "workerID" in libE_specs else False
@@ -528,21 +591,20 @@ def libE_tcp_start_team(manager, nworkers, workers, ip, port, authkey, launchf):
     specs = {"manager_ip": ip, "manager_port": port, "authkey": authkey}
     with Timer() as timer:
         for w in range(1, nworkers + 1):
-            logger.info("Manager is launching worker {}".format(w))
+            logger.info(f"Manager is launching worker {w}")
             if workers is not None:
                 specs["worker_ip"] = workers[w - 1]
                 specs["tunnel_port"] = 0x71BE
             specs["workerID"] = w
             worker_procs.append(launchf(specs))
-        logger.info("Manager is awaiting {} workers".format(nworkers))
+        logger.info(f"Manager is awaiting {nworkers} workers")
         wcomms = manager.await_workers(nworkers)
-        logger.info("Manager connected to {} workers ({} s)".format(nworkers, timer.elapsed))
+        logger.info(f"Manager connected to {nworkers} workers ({timer.elapsed} s)")
     return worker_procs, wcomms
 
 
 def libE_tcp_mgr(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs, libE_specs, H0):
     """Main routine for TCP multiprocessing launch of libE at manager."""
-
     hist = History(alloc_specs, sim_specs, gen_specs, exit_criteria, H0)
 
     # Set up a worker launcher
@@ -559,8 +621,6 @@ def libE_tcp_mgr(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs,
     port = libE_specs.get("port", 0)
     authkey = libE_specs.get("authkey", libE_tcp_authkey())
 
-    osx_set_mp_method()
-
     with ServerQCommManager(port, authkey.encode("utf-8")) as tcp_manager:
 
         # Get port if needed because of auto-assignment
@@ -568,9 +628,11 @@ def libE_tcp_mgr(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs,
             _, port = tcp_manager.address
 
         if not libE_specs.get("disable_log_files", False):
-            manager_logging_config()
+            exit_logger = manager_logging_config()
+        else:
+            exit_logger = None
 
-        logger.info("Launched server at ({}, {})".format(ip, port))
+        logger.info(f"Launched server at ({ip}, {port})")
 
         # Launch worker team and set up logger
         worker_procs, wcomms = libE_tcp_start_team(tcp_manager, nworkers, workers, ip, port, authkey, launchf)
@@ -579,6 +641,8 @@ def libE_tcp_mgr(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs,
             """Handler to clean up launched team."""
             for wp in worker_procs:
                 launcher.cancel(wp, timeout=libE_specs.get("worker_timeout"))
+            if exit_logger is not None:
+                exit_logger()
 
         # Run generic manager
         return manager(
@@ -588,7 +652,6 @@ def libE_tcp_mgr(sim_specs, gen_specs, exit_criteria, persis_info, alloc_specs,
 
 def libE_tcp_worker(sim_specs, gen_specs, libE_specs):
     """Main routine for TCP worker launched by libE."""
-
     ip = libE_specs["ip"]
     port = libE_specs["port"]
     authkey = libE_specs["authkey"]
@@ -596,7 +659,7 @@ def libE_tcp_worker(sim_specs, gen_specs, libE_specs):
 
     with ClientQCommManager(ip, port, authkey, workerID) as comm:
         worker_main(comm, sim_specs, gen_specs, libE_specs, workerID=workerID, log_comm=True)
-        logger.debug("Worker {} exiting".format(workerID))
+        logger.debug(f"Worker {workerID} exiting")
 
 
 # ==================== Additional Internal Functions ===========================
@@ -605,7 +668,7 @@ def libE_tcp_worker(sim_specs, gen_specs, libE_specs):
 def _dump_on_abort(hist, persis_info, save_H=True):
     """Dump history and persis_info on abort"""
     logger.error("Manager exception raised .. aborting ensemble:")
-    logger.error("Dumping ensemble history with {} sims evaluated:".format(hist.sim_ended_count))
+    logger.error(f"Dumping ensemble history with {hist.sim_ended_count} sims evaluated:")
 
     if save_H:
         np.save("libE_history_at_abort_" + str(hist.sim_ended_count) + ".npy", hist.trim_H())
