@@ -52,13 +52,11 @@ class Resources:
     @classmethod
     def init_resources(cls, libE_specs):
         """Initiate resource management"""
-
         # If disable_resource_manager is True, then Resources.resources will remain None.
         disable_resource_manager = libE_specs.get("disable_resource_manager", False)
         if not disable_resource_manager:
             top_level_dir = os.getcwd()
-            if Resources.resources is None:
-                Resources.resources = Resources(libE_specs=libE_specs, top_level_dir=top_level_dir)
+            Resources.resources = Resources(libE_specs=libE_specs, top_level_dir=top_level_dir)
 
     def __init__(self, libE_specs, top_level_dir=None):
         """Initiate a new resources object"""
@@ -164,9 +162,6 @@ class GlobalResources:
         self.num_resource_sets = libE_specs.get("num_resource_sets", None)
         self.enforce_worker_core_bounds = libE_specs.get("enforce_worker_core_bounds", False)
 
-        if self.dedicated_mode:
-            logger.debug("Running in central mode")
-
         resource_info = libE_specs.get("resource_info", {})
         cores_on_node = resource_info.get("cores_on_node", None)
         node_file = resource_info.get("node_file", None)
@@ -200,7 +195,7 @@ class GlobalResources:
         # Note: Launcher used here just to get cores on node etc - independent of whether using MPIExecutor
         self.launcher = get_MPI_runner()
         remote_detect = False
-        if self.local_host not in self.global_nodelist:
+        if self.local_host not in self.global_nodelist and self.launcher is not None:
             remote_detect = True
 
         if not cores_on_node:
@@ -228,6 +223,7 @@ class GlobalResources:
                 self.global_nodelist = GlobalResources.remove_nodes(self.global_nodelist, self.libE_nodes)
                 if not self.global_nodelist:
                     logger.warning("Warning. Node-list for tasks is empty. Remove dedicated_mode or add nodes")
+                    pass
 
     @staticmethod
     def is_nodelist_shortnames(nodelist):
@@ -237,7 +233,7 @@ class GlobalResources:
                 return False
         return True
 
-    # This is for central mode where libE nodes will not share with app nodes
+    # This is for dedicated mode where libE nodes will not share with app nodes
     @staticmethod
     def remove_nodes(global_nodelist_in, remove_list):
         """Removes any nodes in remove_list from the global nodelist"""
@@ -253,24 +249,21 @@ class GlobalResources:
         is interrogated for a node list. If a dedicated manager node is used,
         then a node_file is recommended.
 
-        In central mode, any node with a libE worker is removed from the list.
+        In dedicated mode, any node with a libE worker is removed from the list.
         """
         top_level_dir = rundir or os.getcwd()
         node_filepath = os.path.join(top_level_dir, node_file)
         global_nodelist = []
         if os.path.isfile(node_filepath):
-            logger.debug("node_file found - getting nodelist from node_file")
             with open(node_filepath, "r") as f:
                 for line in f:
                     global_nodelist.append(line.rstrip())
         else:
-            logger.debug("No node_file found - searching for nodelist in environment")
             if env_resources:
                 global_nodelist = env_resources.get_nodelist()
 
             if not global_nodelist:
                 # Assume a standalone machine
-                logger.info("Can not find nodelist from environment. Assuming standalone")
                 # global_nodelist.append(env_resources.shortnames([socket.gethostname()])[0])
                 global_nodelist.append(socket.gethostname())
 
