@@ -65,7 +65,6 @@ class ResourceManager(RSetResources):
 
     def assign_rsets(self, rset_team, worker_id):
         """Mark the resource sets given by rset_team as assigned to worker_id"""
-
         if rset_team:
             rteam = self.rsets["assigned"][rset_team]
             for i, wid in enumerate(rteam):
@@ -74,8 +73,7 @@ class ResourceManager(RSetResources):
                     self.rsets_free -= 1
                 elif wid != worker_id:
                     ResourceManagerException(
-                        "Error: Attempting to assign rsets {}"
-                        " already assigned to workers: {}".format(rset_team, rteam)
+                        f"Error: Attempting to assign rsets {rset_team}" f" already assigned to workers: {rteam}"
                     )
 
     def free_rsets(self, worker=None):
@@ -307,7 +305,6 @@ class WorkerResources(RSetResources):
     @staticmethod
     def get_local_nodelist(workerID, rset_team, split_list, rsets_per_node):
         """Returns the list of nodes available to the given worker and the slot dictionary"""
-
         if workerID is None:
             raise WorkerResourcesException("Worker has no workerID - aborting")
 
@@ -316,7 +313,7 @@ class WorkerResources(RSetResources):
             team_list += split_list[index]
 
         local_nodelist = list(OrderedDict.fromkeys(team_list))  # Maintain order of nodes
-        logger.debug("Worker's local_nodelist is {}".format(local_nodelist))
+        logger.debug(f"Worker's local_nodelist is {local_nodelist}")
 
         slots = {}
         for node in local_nodelist:
