@@ -1,4 +1,4 @@
-__all__ = ['geomedian_eval']
+__all__ = ["geomedian_eval"]
 import numpy as np
 import numpy.linalg as la
 
@@ -9,11 +9,11 @@ def EvaluateFunction(x, component, B):
     """
     m = B.shape[0]
     assert B.shape[1] == len(x)
-    assert 0 <= component <= m-1
+    assert 0 <= component <= m - 1
     i = component
     b_i = B[i]
 
-    f_i = 1.0/m * la.norm(x-b_i)
+    f_i = 1.0 / m * la.norm(x - b_i)
     return f_i
 
 
@@ -23,27 +23,27 @@ def EvaluateJacobian(x, component, B):
     """
     m = B.shape[0]
     assert B.shape[1] == len(x)
-    assert 0 <= component <= m-1
+    assert 0 <= component <= m - 1
     i = component
     b_i = B[i]
 
-    df_i = 1.0/m * (x-b_i)/la.norm(x-b_i)
+    df_i = 1.0 / m * (x - b_i) / la.norm(x - b_i)
     return df_i
 
 
 def geomedian_eval(H, persis_info, sim_specs, _):
 
-    B = persis_info['params']['B']
+    B = persis_info["params"]["B"]
 
-    num_xs = len(H['x'])  # b==1 always?
-    H_o = np.zeros(num_xs, dtype=sim_specs['out'])
+    num_xs = len(H["x"])  # b==1 always?
+    H_o = np.zeros(num_xs, dtype=sim_specs["out"])
 
-    for k, x in enumerate(H['x']):
-        i = H[k]['obj_component']   # f_i
+    for k, x in enumerate(H["x"]):
+        i = H[k]["obj_component"]  # f_i
 
-        if H[k]['get_grad']:
-            H_o['gradf_i'][k] = EvaluateJacobian(x, i, B)
+        if H[k]["get_grad"]:
+            H_o["gradf_i"][k] = EvaluateJacobian(x, i, B)
         else:
-            H_o['f_i'][k] = EvaluateFunction(x, i, B)
+            H_o["f_i"][k] = EvaluateFunction(x, i, B)
 
     return H_o, persis_info
