@@ -51,6 +51,6 @@ python $EXE $COMMS $NWORKERS > out.txt 2>&1
 
 if [[ $LIBE_PLOTS = "true" ]]; then
   python $PLOT_DIR/plot_libe_calcs_util_v_time.py
-  python $PLOT_DIR/plot_libe_runs_util_v_time.py
+  python $PLOT_DIR/plot_libe_tasks_util_v_time.py
   python $PLOT_DIR/plot_libe_histogram.py
 fi
