@@ -16,8 +16,8 @@ runline.append("python")
 runline.append("helloworld.py")
 
 if rank == 0:
-    print("Total sub-task procs: {}".format(size * int(task_nprocs)))
-    print("Total procs (parent + sub-tasks): {}".format(size * (int(task_nprocs) + 1)))
+    print(f"Total sub-task procs: {size * int(task_nprocs)}")
+    print(f"Total procs (parent + sub-tasks): {size * (int(task_nprocs) + 1)}")
 
 # print("Rank {}: {}".format(rank, " ".join(runline)))
 output = "task_" + str(rank) + ".out"
