@@ -7,10 +7,13 @@ import sys
 import time
 import pytest
 import socket
-import mpi4py
+import platform
 
-mpi4py.rc.initialize = False
-from mpi4py import MPI
+if platform.system() != "Windows":
+    import mpi4py
+
+    mpi4py.rc.initialize = False
+    from mpi4py import MPI
 
 from libensemble.resources.mpi_resources import MPIResourcesException
 from libensemble.executors.executor import Executor, ExecutorException, TimeoutExpired
@@ -25,13 +28,14 @@ sim_app = "simdir/my_simtask.x"
 serial_app = "simdir/my_serialtask.x"
 c_startup = "simdir/c_startup.x"
 py_startup = "simdir/py_startup.py"
+non_existent_app = "simdir/non_exist.x"
 
 
 def setup_module(module):
     try:
-        print("setup_module module:%s" % module.__name__)
+        print(f"setup_module module:{module.__name__}")
     except AttributeError:
-        print("setup_module (direct run) module:%s" % module)
+        print(f"setup_module (direct run) module:{module}")
     if Executor.executor is not None:
         del Executor.executor
         Executor.executor = None
@@ -39,7 +43,7 @@ def setup_module(module):
 
 
 def setup_function(function):
-    print("setup_function function:%s" % function.__name__)
+    print(f"setup_function function:{function.__name__}")
     if Executor.executor is not None:
         del Executor.executor
         Executor.executor = None
@@ -47,9 +51,9 @@ def setup_function(function):
 
 def teardown_module(module):
     try:
-        print("teardown_module module:%s" % module.__name__)
+        print(f"teardown_module module:{module.__name__}")
     except AttributeError:
-        print("teardown_module (direct run) module:%s" % module)
+        print(f"teardown_module (direct run) module:{module}")
     if Executor.executor is not None:
         del Executor.executor
         Executor.executor = None
@@ -69,7 +73,7 @@ def build_simfuncs():
 def setup_executor():
     """Set up an MPI Executor with sim app"""
     if USE_BALSAM:
-        from libensemble.executors.balsam_executor import LegacyBalsamMPIExecutor
+        from libensemble.executors.balsam_executors import LegacyBalsamMPIExecutor
 
         exctr = LegacyBalsamMPIExecutor()
     else:
@@ -99,7 +103,7 @@ def setup_executor_startups():
 def setup_executor_noapp():
     """Set up an MPI Executor but do not register application"""
     if USE_BALSAM:
-        from libensemble.executors.balsam_executor import LegacyBalsamMPIExecutor
+        from libensemble.executors.balsam_executors import LegacyBalsamMPIExecutor
 
         exctr = LegacyBalsamMPIExecutor()
     else:
@@ -201,9 +205,12 @@ def polling_loop_multitask(exctr, task_list, timeout_sec=4.0, delay=0.05):
 
 
 # Tests ========================================================================================
+
+
+@pytest.mark.extra
 def test_launch_and_poll():
     """Test of launching and polling task and exiting on task finish"""
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -215,9 +222,10 @@ def test_launch_and_poll():
     assert task.run_attempts == 1, "task.run_attempts should be 1. Returned " + str(task.run_attempts)
 
 
+@pytest.mark.extra
 def test_launch_and_wait():
     """Test of launching and waiting on task"""
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -231,9 +239,10 @@ def test_launch_and_wait():
     assert task.state == "FINISHED", "task.state should be FINISHED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_launch_and_wait_timeout():
     """Test of launching and waiting on task timeout (and kill)"""
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -250,9 +259,10 @@ def test_launch_and_wait_timeout():
     assert task.state == "USER_KILLED", "task.state should be USER_KILLED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_launch_wait_on_start():
     """Test of launching task with wait_on_start"""
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -266,9 +276,10 @@ def test_launch_wait_on_start():
     assert task.state == "FINISHED", "task.state should be FINISHED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_kill_on_file():
     """Test of killing task based on something in output file"""
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -279,8 +290,9 @@ def test_kill_on_file():
     assert task.state == "USER_KILLED", "task.state should be USER_KILLED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_kill_on_timeout():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -291,8 +303,9 @@ def test_kill_on_timeout():
     assert task.state == "USER_KILLED", "task.state should be USER_KILLED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_kill_on_timeout_polling_loop_method():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -303,8 +316,9 @@ def test_kill_on_timeout_polling_loop_method():
     assert task.state == "USER_KILLED", "task.state should be USER_KILLED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_launch_and_poll_multitasks():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     task_list = []
@@ -325,9 +339,10 @@ def test_launch_and_poll_multitasks():
         assert task.state == "FINISHED", "task.state should be FINISHED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_get_task():
     """Return task from given task id"""
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
 
@@ -340,7 +355,7 @@ def test_get_task():
     args_for_sim = "sleep 0"
     task0 = exctr.submit(calc_type="sim", num_procs=cores, app_args=args_for_sim)
     taskid = task0.id
-    print("taskid is: {}".format(taskid))
+    print(f"taskid is: {taskid}")
     A = exctr.get_task(taskid)
     assert A is task0, "Task get_task returned unexpected task" + str(A)
     task0 = polling_loop(exctr, task0)
@@ -350,10 +365,11 @@ def test_get_task():
     assert A is None, "Task found when supplied taskid should not exist"
 
 
+@pytest.mark.extra
 @pytest.mark.timeout(30)
 def test_procs_and_machinefile_logic():
     """Test of supplying various input configurations."""
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
 
     # Note: Could test task_partition routine directly - without launching tasks...
 
@@ -436,13 +452,14 @@ def test_procs_and_machinefile_logic():
     assert task.state == "FINISHED", "task.state should be FINISHED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 @pytest.mark.timeout(20)
 def test_doublekill():
     """Test attempt to kill already killed task
 
     Kill should have no effect (except warning message) and should remain in state killed
     """
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -459,13 +476,14 @@ def test_doublekill():
     assert task.state == "USER_KILLED", "task.state should be USER_KILLED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 @pytest.mark.timeout(20)
 def test_finish_and_kill():
     """Test attempt to kill already finished task
 
     Kill should have no effect (except warning message) and should remain in state FINISHED
     """
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -485,10 +503,11 @@ def test_finish_and_kill():
     assert task.state == "FINISHED", "task.state should be FINISHED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 @pytest.mark.timeout(20)
 def test_launch_and_kill():
     """Test launching and immediately killing tasks with no poll"""
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -505,8 +524,9 @@ def test_launch_and_kill():
         assert task.state == "USER_KILLED", "task.state should be USER_KILLED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_launch_as_gen():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -535,8 +555,9 @@ def test_launch_as_gen():
         assert 0
 
 
+@pytest.mark.extra
 def test_launch_no_app():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor_noapp()
     exctr = Executor.executor
     cores = NCORES
@@ -555,10 +576,11 @@ def test_launch_no_app():
         assert 0
 
 
+@pytest.mark.extra
 def test_kill_task_with_no_submit():
     from libensemble.executors.executor import Task
 
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
 
@@ -585,10 +607,11 @@ def test_kill_task_with_no_submit():
         assert 0
 
 
+@pytest.mark.extra
 def test_poll_task_with_no_submit():
     from libensemble.executors.executor import Task
 
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
 
@@ -605,8 +628,9 @@ def test_poll_task_with_no_submit():
         assert 0
 
 
+@pytest.mark.extra
 def test_task_failure():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -617,8 +641,9 @@ def test_task_failure():
     assert task.state == "FAILED", "task.state should be FAILED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_retries_launch_fail():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor_fakerunner()
     exctr = Executor.executor
     exctr.retry_delay_incr = 0.05
@@ -630,8 +655,9 @@ def test_retries_launch_fail():
     assert task.run_attempts == 5, "task.run_attempts should be 5. Returned " + str(task.run_attempts)
 
 
+@pytest.mark.extra
 def test_retries_run_fail():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     exctr.retry_delay_incr = 0.05
@@ -643,12 +669,14 @@ def test_retries_run_fail():
     assert task.run_attempts == 5, "task.run_attempts should be 5. Returned " + str(task.run_attempts)
 
 
+@pytest.mark.extra
 def test_register_apps():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()  # This registers an app my_simtask.x (default sim)
     exctr = Executor.executor
     exctr.register_app(full_path="/path/to/fake_app1.x", app_name="fake_app1")
     exctr.register_app(full_path="/path/to/fake_app2.py", app_name="fake_app2")
+    exctr.register_app(full_path="/path/to/fake_app3.pl", app_name="fake_app3", precedent="perl")
 
     # Check selected attributes
     app = exctr.get_app("my_simtask.x")
@@ -660,23 +688,34 @@ def test_register_apps():
     assert app.gname == "libe_app_fake_app1"
     assert app.exe == "fake_app1.x"
     assert app.calc_dir == "/path/to"
+    assert app.app_cmd == "/path/to/fake_app1.x"
+    assert not app.precedent
 
     app = exctr.get_app("fake_app2")
     assert app.name == "fake_app2"
     assert app.gname == "libe_app_fake_app2"
+    assert app.full_path == "/path/to/fake_app2.py"
 
-    py_exe, app_exe = app.full_path.split()
+    py_exe, app_exe = app.app_cmd.split()
     assert os.path.split(py_exe)[1].startswith("python")
     assert app_exe == "/path/to/fake_app2.py"
 
+    app = exctr.get_app("fake_app3")
+    assert app.name == "fake_app3"
+    assert app.gname == "libe_app_fake_app3"
+    assert app.full_path == "/path/to/fake_app3.pl"
+    assert app.precedent == "perl"
+    assert app.app_cmd == "perl /path/to/fake_app3.pl"
+
     try:
-        app = exctr.get_app("fake_app3")
+        app = exctr.get_app("fake_app4")
     except ExecutorException as e:
-        assert e.args[0] == "Application fake_app3 not found in registry"
+        assert e.args[0] == "Application fake_app4 not found in registry"
         # Ordering of dictionary may vary
         # assert e.args[1] == "Registered applications: ['my_simtask.x', 'fake_app1', 'fake_app2']"
 
 
+@pytest.mark.extra
 def test_serial_exes():
     setup_serial_executor()
     exctr = Executor.executor
@@ -687,6 +726,7 @@ def test_serial_exes():
     assert task.state == "FINISHED", "task.state should be FINISHED. Returned " + str(task.state)
 
 
+@pytest.mark.extra
 def test_serial_startup_times():
     setup_executor_startups()
     exctr = Executor.executor
@@ -712,8 +752,9 @@ def test_serial_startup_times():
     assert 0 < startup_time < 1, "Start up time for python program took " + str(startup_time)
 
 
+@pytest.mark.extra
 def test_futures_interface():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     cores = NCORES
     args_for_sim = "sleep 3"
@@ -725,8 +766,9 @@ def test_futures_interface():
     assert task.done(), "task.done() should return True after task finishes."
 
 
+@pytest.mark.extra
 def test_futures_interface_cancel():
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     cores = NCORES
     args_for_sim = "sleep 3"
@@ -737,9 +779,10 @@ def test_futures_interface_cancel():
     assert task.cancelled() and task.done(), "Task should be both cancelled() and done() after cancellation."
 
 
+@pytest.mark.extra
 def test_dry_run():
     """Test of dry_run in poll"""
-    print("\nTest: {}\n".format(sys._getframe().f_code.co_name))
+    print(f"\nTest: {sys._getframe().f_code.co_name}\n")
     setup_executor()
     exctr = Executor.executor
     cores = NCORES
@@ -749,6 +792,46 @@ def test_dry_run():
     task.kill()
 
 
+@pytest.mark.extra
+def test_non_existent_app():
+    """Tests exception on non-existent app"""
+    from libensemble.executors.executor import Executor
+
+    exctr = Executor()
+
+    # Can register a non-existent app in case created as part of workflow.
+    exctr.register_app(full_path=non_existent_app, app_name="nonexist")
+
+    w_exctr = Executor.executor  # simulate on worker
+
+    try:
+        w_exctr.submit(app_name="nonexist")
+    except ExecutorException as e:
+        assert e.args[0] == "Application does not exist simdir/non_exist.x"
+    else:
+        assert 0
+
+
+@pytest.mark.extra
+def test_non_existent_app_mpi():
+    """Tests exception on non-existent app"""
+    from libensemble.executors.mpi_executor import MPIExecutor
+
+    exctr = MPIExecutor()
+
+    # Can register a non-existent app in case created as part of workflow.
+    exctr.register_app(full_path=non_existent_app, app_name="nonexist")
+
+    w_exctr = Executor.executor  # simulate on worker
+
+    try:
+        w_exctr.submit(app_name="nonexist")
+    except ExecutorException as e:
+        assert e.args[0] == "Application does not exist simdir/non_exist.x"
+    else:
+        assert 0
+
+
 if __name__ == "__main__":
     setup_module(__file__)
     test_launch_and_poll()
@@ -777,4 +860,6 @@ if __name__ == "__main__":
     test_futures_interface()
     test_futures_interface_cancel()
     test_dry_run()
+    test_non_existent_app()
+    test_non_existent_app_mpi()
     teardown_module(__file__)
