@@ -1,44 +1,40 @@
 import os
+import pytest
 import shutil
 import numpy as np
 from libensemble.output_directory import EnsembleDirectory
 from libensemble.utils.loc_stack import LocationStack
+from libensemble.utils.misc import extract_H_ranges
 
 
 def test_range_single_element():
     """Single H_row labeling"""
-
     work = {"H_fields": ["x", "num_nodes", "procs_per_node"], "libE_info": {"H_rows": np.array([5]), "workerID": 1}}
-    assert EnsembleDirectory.extract_H_ranges(work) == "5", "Failed to correctly parse single H row"
+    assert extract_H_ranges(work) == "5", "Failed to correctly parse single H row"
 
 
 def test_range_two_separate_elements():
     """Multiple H_rows, non-sequential"""
-
     work = {"H_fields": ["x", "num_nodes", "procs_per_node"], "libE_info": {"H_rows": np.array([2, 8]), "workerID": 1}}
-    assert EnsembleDirectory.extract_H_ranges(work) == "2_8", "Failed to correctly parse nonsequential H rows"
+    assert extract_H_ranges(work) == "2_8", "Failed to correctly parse nonsequential H rows"
 
 
 def test_range_two_ranges():
     """Multiple sequences of H_rows"""
-
     work = {
         "H_fields": ["x", "num_nodes", "procs_per_node"],
         "libE_info": {"H_rows": np.array([0, 1, 2, 3, 7, 8]), "workerID": 1},
     }
-    assert EnsembleDirectory.extract_H_ranges(work) == "0-3_7-8", "Failed to correctly parse multiple H ranges"
+    assert extract_H_ranges(work) == "0-3_7-8", "Failed to correctly parse multiple H ranges"
 
 
 def test_range_mixes():
     """Mix of single rows and sequences of H_rows"""
-
     work = {
         "H_fields": ["x", "num_nodes", "procs_per_node"],
         "libE_info": {"H_rows": np.array([2, 3, 4, 6, 8, 9, 11, 14]), "workerID": 1},
     }
-    assert (
-        EnsembleDirectory.extract_H_ranges(work) == "2-4_6_8-9_11_14"
-    ), "Failed to correctly parse H row single elements and ranges."
+    assert extract_H_ranges(work) == "2-4_6_8-9_11_14", "Failed to correctly parse H row single elements and ranges."
 
 
 def test_copy_back():
@@ -88,6 +84,7 @@ def test_worker_dirs_but_no_sim_dirs():
         shutil.rmtree(dir)
 
 
+@pytest.mark.extra
 def test_loc_stack_FileExists_exceptions():
     inputdir = "./calc"
     copyfile = "./calc/copy"
